# Reference: https://www.loc.gov/catdir/cpso/romanization/amharic.pdf

_transliteration = {
    # Syllables
    'ሀ': ['ha'],
    'ሁ': ['hu'],
    'ሂ': ['hi'],
    'ሃ': ['hā'],
    'ሄ': ['hé'],
    'ህ': ['he', 'h'],
    'ሆ': ['ho'],
    'ለ': ['la'],
    'ሉ': ['lu'],
    'ሊ': ['li'],
    'ላ': ['lā'],
    'ሌ': ['lé'],
    'ል': ['le', 'l'],
    'ሎ': ['lo'],
    'ሐ': ['ḥa'],
    'ሑ': ['ḥu'],
    'ሒ': ['ḥi'],
    'ሓ': ['ḥā'],
    'ሔ': ['ḥé'],
    'ሕ': ['ḥe', 'ḥ'],
    'ሖ': ['ḥo'],
    'መ': ['ma'],
    'ሙ': ['mu'],
    'ሚ': ['mi'],
    'ማ': ['mā'],
    'ሜ': ['mé'],
    'ም': ['me', 'm'],
    'ሞ': ['mo'],
    'ሠ': ['śa'],
    'ሡ': ['śu'],
    'ሢ': ['śi'],
    'ሣ': ['śā'],
    'ሤ': ['śé'],
    'ሥ': ['śe', 'ś'],
    'ሦ': ['śo'],
    'ረ': ['ra'],
    'ሩ': ['ru'],
    'ሪ': ['ri'],
    'ራ': ['rā'],
    'ሬ': ['ré'],
    'ር': ['re', 'r'],
    'ሮ': ['ro'],
    'ሰ': ['sa'],
    'ሱ': ['su'],
    'ሲ': ['si'],
    'ሳ': ['sā'],
    'ሴ': ['sé'],
    'ስ': ['se', 's'],
    'ሶ': ['so'],
    'ሸ': ['ša'],
    'ሹ': ['šu'],
    'ሺ': ['ši'],
    'ሻ': ['šā'],
    'ሼ': ['šé'],
    'ሽ': ['še', 'š'],
    'ሾ': ['šo'],
    'ቀ': ['qa'],
    'ቁ': ['qu'],
    'ቂ': ['qi'],
    'ቃ': ['qā'],
    'ቄ': ['qé'],
    'ቅ': ['qe', 'q'],
    'ቆ': ['qo'],
    'በ': ['ba'],
    'ቡ': ['bu'],
    'ቢ': ['bi'],
    'ባ': ['bā'],
    'ቤ': ['bé'],
    'ብ': ['be', 'b'],
    'ቦ': ['bo'],
    'ተ': ['ta'],
    'ቱ': ['tu'],
    'ቲ': ['ti'],
    'ታ': ['tā'],
    'ቴ': ['té'],
    'ት': ['te', 't'],
    'ቶ': ['to'],
    'ቸ': ['ča'],
    'ቹ': ['ču'],
    'ቺ': ['či'],
    'ቻ': ['čā'],
    'ቼ': ['čé'],
    'ች': ['če', 'č'],
    'ቾ': ['čo'],
    'ኀ': ['ha'],
    'ኁ': ['hu'],
    'ኂ': ['hi'],
    'ኃ': ['hā'],
    'ኄ': ['hé'],
    'ኅ': ['he', 'h'],
    'ኆ': ['ho'],
    'ነ': ['na'],
    'ኑ': ['nu'],
    'ኒ': ['ni'],
    'ና': ['nā'],
    'ኔ': ['né'],
    'ን': ['ne', 'n'],
    'ኖ': ['no'],
    'ኘ': ['ña'],
    'ኙ': ['ñu'],
    'ኚ': ['ñi'],
    'ኛ': ['ñā'],
    'ኜ': ['ñé'],
    'ኝ': ['ñe', 'ñ'],
    'ኞ': ['ño'],
    'አ': ['ʼa'],
    'ኡ': ['ʼu'],
    'ኢ': ['ʼi'],
    'ኣ': ['ʼā'],
    'ኤ': ['ʼé'],
    'እ': ['ʼe'],
    'ኦ': ['ʼo'],
    'ከ': ['ka'],
    'ኩ': ['ku'],
    'ኪ': ['ki'],
    'ካ': ['kā'],
    'ኬ': ['ké'],
    'ክ': ['ke', 'k'],
    'ኮ': ['ko'],
    'ኸ': ['xa'],
    'ኹ': ['xu'],
    'ኺ': ['xi'],
    'ኻ': ['xā'],
    'ኼ': ['xé'],
    'ኽ': ['xe', 'x'],
    'ኾ': ['xo'],
    'ወ': ['wa'],
    'ዉ': ['wu'],
    'ዊ': ['wi'],
    'ዋ': ['wā'],
    'ዌ': ['wé'],
    'ው': ['we', 'w'],
    'ዎ': ['wo'],
    'ዐ': ['ʻa'],
    'ዑ': ['ʻu'],
    'ዒ': ['ʻi'],
    'ዓ': ['ʻā'],
    'ዔ': ['ʻé'],
    'ዕ': ['ʻe'],
    'ዖ': ['ʻo'],
    'ዘ': ['za'],
    'ዙ': ['zu'],
    'ዚ': ['zi'],
    'ዛ': ['zā'],
    'ዜ': ['zé'],
    'ዝ': ['ze', 'z'],
    'ዞ': ['zo'],
    'ዠ': ['ža'],
    'ዡ': ['žu'],
    'ዢ': ['ži'],
    'ዣ': ['žā'],
    'ዤ': ['žé'],
    'ዥ,ዥ': ['že', 'ž'],
    'ዦ': ['žo'],
    'የ': ['ya'],
    'ዩ': ['yu'],
    'ዪ': ['yi'],
    'ያ': ['yā'],
    'ዬ': ['yé'],
    'ይ': ['ye', 'y'],
    'ዮ': ['yo'],
    'ደ': ['da'],
    'ዱ': ['du'],
    'ዲ': ['di'],
    'ዳ': ['dā'],
    'ዴ': ['dé'],
    'ድ': ['de', 'd'],
    'ዶ': ['do'],
    'ጀ': ['ǧa'],
    'ጁ': ['ǧu'],
    'ጂ': ['ǧi'],
    'ጃ': ['ǧā'],
    'ጄ': ['ǧé'],
    'ጅ': ['ǧe', 'ǧ'],
    'ጆ': ['ǧo'],
    'ገ': ['ga'],
    'ጉ': ['gu'],
    'ጊ': ['gi'],
    'ጋ': ['gā'],
    'ጌ': ['gé'],
    'ግ': ['ge', 'g'],
    'ጎ': ['go'],
    'ጠ': ['ṭa'],
    'ጡ': ['ṭu'],
    'ጢ': ['ṭi'],
    'ጣ': ['ṭā'],
    'ጤ': ['ṭé'],
    'ጥ': ['ṭe', 'ṭ'],
    'ጦ': ['ṭo'],
    'ጨ': ['ċa'],
    'ጩ': ['ċu'],
    'ጪ': ['ċi'],
    'ጫ': ['ċā'],
    'ጬ': ['ċé'],
    'ጭ': ['ċe', 'ċ'],
    'ጮ': ['ċo'],
    'ጰ': ['p̣a'],
    'ጱ': ['p̣u'],
    'ጲ': ['p̣i'],
    'ጳ': ['p̣ā'],
    'ጴ': ['p̣é'],
    'ጵ': ['p̣e', 'p̣'],
    'ጶ': ['p̣o'],
    'ጸ': ['ṣa'],
    'ጹ': ['ṣu'],
    'ጺ': ['ṣi'],
    'ጻ': ['ṣā'],
    'ጼ': ['ṣé'],
    'ጽ': ['ṣe', 'ṣ'],
    'ጾ': ['ṣo'],
    'ፀ': ['ṡa'],
    'ፁ': ['ṡu'],
    'ፂ': ['ṡi'],
    'ፃ': ['ṡā'],
    'ፄ': ['ṡé'],
    'ፅ': ['ṡe', 'ṡ'],
    'ፆ': ['ṡo'],
    'ፈ': ['fa'],
    'ፉ': ['fu'],
    'ፊ': ['fi'],
    'ፋ': ['fā'],
    'ፌ': ['fé'],
    'ፍ': ['fe', 'f'],
    'ፎ': ['fo'],
    'ፐ': ['pa'],
    'ፑ': ['pu'],
    'ፒ': ['pi'],
    'ፓ': ['pā'],
    'ፔ': ['pé'],
    'ፕ': ['pe', 'p'],
    'ፖ': ['po'],
    'ቨ': ['va'],
    'ቩ': ['vu'],
    'ቪ': ['vi'],
    'ቫ': ['vā'],
    'ቬ': ['vé'],
    'ቭ': ['ve', 'v'],
    'ቮ': ['vo'],
    # Combinations with w
    'ቈ': ['qwa'],
    'ቊ': ['qwi'],
    'ቋ': ['qwā'],
    'ቌ': ['qwé'],
    'ቍ': ['qwe'],
    'ኈ': ['hwa'],
    'ኊ': ['hwi'],
    'ኋ': ['hwā'],
    'ኌ': ['hwé'],
    'ኍ': ['hwe'],
    'ኰ': ['kwa'],
    'ኲ': ['kwi'],
    'ኳ': ['kwā'],
    'ኴ': ['kwé'],
    'ኵ': ['kwe'],
    'ጐ': ['gwa'],
    'ጒ': ['gwi'],
    'ጓ': ['gwā'],
    'ጔ': ['gwé'],
    'ጕ': ['gwe'],
    # Combinations with wa
    'ሏ': ['lwa'],
    'ቧ': ['bwa'],
    'ዟ': ['zwa'],
    'ጧ': ['ṭwā'],
    'ሟ': ['mwa'],
    'ቷ': ['twa'],
    'ዧ': ['žwa'],
    'ጯ': ['ċwā'],
    'ሯ': ['rwa'],
    'ቿ': ['čwa'],
    'ጿ': ['ṣwā'],
    'ሷ': ['swa'],
    'ኗ': ['nwa'],
    'ዷ': ['dwa'],
    'ፏ': ['fwā'],
    'ሿ': ['šwa'],
    'ኟ': ['ñwa'],
    'ጇ': ['ǧwa'],
    # Combinations with ya
    'ፘ':['rya'],
    'ፙ':['mya'],
    'ፚ':['fya'],
    # Special initial
    'ኧ': ['ă']
}


def romanize(text):
    output = ''
    for char in text:
        try:
            output += _transliteration[char][-1]
        except KeyError:
            output += char

    return output


if __name__ == '__main__':
    print(f"{romanize('ሰላም እንደምን አለህ?').capitalize()}")

